@@ -1,6 +1,6 @@
 """KayPENTAX Disordered Voice Database Reader module"""
 
-__version__ = "0.3.1"
+__version__ = "0.4.0"
 
 import pandas as pd
 from os import path
@@ -11,7 +11,7 @@ import nspfile
 
 
 class KPDVDB:
-    def __init__(self, dbdir):
+    def __init__(self, dbdir, remove_unknowns=False):
         """KPDVDB constructor
 
         :param dbdir: path to the cdrom drive or the directory hosting a copy of the database
@@ -25,9 +25,9 @@ class KPDVDB:
         self._dx = None  # patient diagnoses series
 
         # load the database
-        self._load_db(dbdir)
+        self._load_db(dbdir, remove_unknowns)
 
-    def _load_db(self, dbdir):
+    def _load_db(self, dbdir, remove_unknowns):
         """load disordered voice database
 
         :param dbdir: path to the cdrom drive or the directory hosting a copy of the database
@@ -71,23 +71,26 @@ class KPDVDB:
         )
 
         # add PAT_ID if missing (use unique ID based on the file name)
-        tf = pd.isna(df["PAT_ID"])
-        for row in np.where(tf)[0]:
-            # id = df.at[row, "FILE VOWEL 'AH'"][:3]
-            # ids = df["PAT_ID"][df["PAT_ID"].str.startswith(id, na=False)].tolist()
-            # if len(ids):
-            #     for i in range(1000):
-            #         id_ = f"{id}{i:03}"
-            #         if id_ not in ids:
-            #             break
-            # else:
-            #     id_ = f"{id}000"
-            # df.at[row, "PAT_ID"] = id_
-            df.at[row, "PAT_ID"] = df.at[row, "FILE VOWEL 'AH'"]
+        if remove_unknowns:
+            df = df[df["PAT_ID"].notna()]
+        else:
+            tf = pd.isna(df["PAT_ID"])
+            for row in np.where(tf)[0]:
+                # id = df.at[row, "FILE VOWEL 'AH'"][:3]
+                # ids = df["PAT_ID"][df["PAT_ID"].str.startswith(id, na=False)].tolist()
+                # if len(ids):
+                #     for i in range(1000):
+                #         id_ = f"{id}{i:03}"
+                #         if id_ not in ids:
+                #             break
+                # else:
+                #     id_ = f"{id}000"
+                # df.at[row, "PAT_ID"] = id_
+                df.at[row, "PAT_ID"] = df.at[row, "FILE VOWEL 'AH'"]
 
         # split dx
-        df_dx = df[["PAT_ID", "VISITDATE", "DIAGNOSIS"]]
-        df.drop(columns=["#", "DIAGNOSIS"], inplace=True)
+        df_dx = df[["PAT_ID", "VISITDATE", "DIAGNOSIS", "LOCATION"]]
+        df.drop(columns=["#", "DIAGNOSIS", "LOCATION"], inplace=True)
         df.drop_duplicates(subset=["PAT_ID", "VISITDATE"], inplace=True)
         df.reset_index(inplace=True, drop=True)
 
@@ -128,7 +131,7 @@ class KPDVDB:
 
         self._dir = dbdir
         self._df = df
-        self._df_dx = df_dx
+        self._df_dx = df_dx[df_dx["DIAGNOSIS"].notna()]
         self._dx = None
 
     def get_fields(self):
@@ -147,14 +150,6 @@ class KPDVDB:
         """
         return self._df["SEX"].cat.categories.tolist()
 
-    def get_locations(self):
-        """get unique entries of LOCATION field
-
-        :return: list of sites of disorders
-        :rtype: list(str)
-        """
-        return self._df["LOCATION"].cat.categories.tolist()
-
     def get_natlangs(self):
         """get unique entries of NATLANGS field
 
@@ -171,13 +166,17 @@ class KPDVDB:
         """
         return self._df["ORIGIN"].cat.categories.tolist()
 
-    def get_diagnoses(self):
+    def get_diagnoses(self, include_locations=False):
         """get unique entries of DIAGNOSIS field
 
+        :param include_locations: True to also return diagnosis locations, defaults to False
+        :type include_locations: bool, optional
         :return: list of diagnoses
         :rtype: list(str)
         """
 
+        if include_locations:
+            return self._df_dx[["DIAGNOSIS", "LOCATION"]].drop_duplicates()
         return self._df_dx["DIAGNOSIS"].cat.categories.tolist()
 
     def _get_dx_series(self):
